@@ -29,6 +29,9 @@
 #include <QTcpServer>
 #include <QUdpSocket>
 
+#include <KSharedConfig>
+#include <KConfigGroup>
+
 #include "../../kdebugnamespace.h"
 #include "landevicelink.h"
 
@@ -44,13 +47,17 @@ void LanLinkProvider::configureSocket(QTcpSocket* socket)
 #endif
 
 #ifdef TCP_KEEPCNT
-    int count = 3;  // send up to 3 keepalive packets out, then disconnect if no response
-    setsockopt(fd, getprotobyname("TCP")->p_proto, TCP_KEEPCNT, &count, sizeof(count));
+    if (getprotobyname("TCP")) {
+        int count = 3;  // send up to 3 keepalive packets out, then disconnect if no response
+        setsockopt(fd, getprotobyname("TCP")->p_proto, TCP_KEEPCNT, &count, sizeof(count));
+    }
 #endif
 
 #ifdef TCP_KEEPINTVL
-    int interval = 5;   // send a keepalive packet out every 2 seconds (after the 5 second idle period)
-    setsockopt(fd, getprotobyname("TCP")->p_proto, TCP_KEEPINTVL, &interval, sizeof(interval));
+    if (getprotobyname("TCP")) {
+        int interval = 5;   // send a keepalive packet out every 2 seconds (after the 5 second idle period)
+        setsockopt(fd, getprotobyname("TCP")->p_proto, TCP_KEEPINTVL, &interval, sizeof(interval));
+    }
 #endif
 
 }
@@ -98,6 +105,8 @@ void LanLinkProvider::onNetworkChange(QNetworkSession::State state)
     NetworkPackage::createIdentityPackage(&np);
     np.set("tcpPort", mTcpPort);
     mUdpSocket.writeDatagram(np.serialize(), QHostAddress("255.255.255.255"), port);
+
+    //TODO: Ping active connections to see if they are still reachable
 }
 
 //I'm the existing device, a new device is kindly introducing itself (I will create a TcpSocket)
@@ -123,17 +132,17 @@ void LanLinkProvider::newUdpConnection()
             delete receivedPackage;
         }
 
-        NetworkPackage np2("");
-        NetworkPackage::createIdentityPackage(&np2);
+        KSharedConfigPtr config = KSharedConfig::openConfig("kdeconnectrc");
+        const QString myId = config->group("myself").readEntry<QString>("id","");
 
-        if (receivedPackage->get<QString>("deviceId") == np2.get<QString>("deviceId")) {
-            //kDebug(kdeconnect_kded()) << "Ignoring my own broadcast";
+            //kDebug(debugArea()) << "Ignoring my own broadcast";
+        if (receivedPackage->get<QString>("deviceId") == myId) {
             return;
         }
 
         int tcpPort = receivedPackage->get<int>("tcpPort", port);
 
-        //kDebug(kdeconnect_kded()) << "Received Udp presentation from" << sender << "asking for a tcp connection on port " << tcpPort;
+        //kDebug(debugArea()) << "Received Udp presentation from" << sender << "asking for a tcp connection on port " << tcpPort;
 
         QTcpSocket* socket = new QTcpSocket(this);
         receivedIdentityPackages[socket].np = receivedPackage;
@@ -166,6 +175,8 @@ void LanLinkProvider::connected()
 
     QTcpSocket* socket = qobject_cast<QTcpSocket*>(sender());
 
+    if (!socket) return;
+
     disconnect(socket, SIGNAL(connected()), this, SLOT(connected()));
     disconnect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
 
@@ -182,7 +193,6 @@ void LanLinkProvider::connected()
 
     bool success = deviceLink->sendPackage(np2);
 
-    //TODO: Use reverse connection too to preffer connecting a unstable device (a phone) to a stable device (a computer)
     if (success) {
 
         //kDebug(debugArea()) << "Handshaking done (i'm the existing device)";
