@@ -22,11 +22,15 @@
 #define MOUSEPADPLUGIN_H
 
 #include <QObject>
+#include <QApplication>
 
 #include <core/kdeconnectplugin.h>
+#include <X11/Xlib.h>
 
 #define PACKAGE_TYPE_MOUSEPAD QLatin1String("kdeconnect.mousepad")
 
+struct FakeKey;
+
 class MousepadPlugin
     : public KdeConnectPlugin
 {
@@ -34,10 +38,16 @@ class MousepadPlugin
 
 public:
     explicit MousepadPlugin(QObject *parent, const QVariantList &args);
+    virtual ~MousepadPlugin();
 
 public Q_SLOTS:
     virtual bool receivePackage(const NetworkPackage& np);
     virtual void connected() { }
+
+private:
+    Display *m_display;
+    FakeKey* m_fakekey;
+
 };
 
 #endif
